==> gnomemeeting-0.94.1.tar.bz2: gnomemeeting-0.94.1/src/toolbar.h <==

/* GnomeMeeting -- A Video-Conferencing application
 * Copyright (C) 2000-2001 Damien Sandras
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *                        toolbar.h  -  description
 *                        -------------------------
 *   begin                : Sat Dec 23 2000
 *   copyright            : (C) 2000-2001 by Damien Sandras
 *   description          : This file contains all the functions needed to
 *                          create the toolbar.
 *   email                : dsandras@seconix.com
 *
 */


#ifndef _TOOLBAR_H_
#define _TOOLBAR_H_

#include <gnome.h>
#include "common.h"


/* DESCRIPTION  :  /
 * BEHAVIOR     :  Create the toolbars and add them to the main window.
 * PRE          :  /
 */
void gnomemeeting_init_toolbar ();


/* DESCRIPTION  :  /
 * BEHAVIOR     :  Updates the connect button.
 * PRE          :  /
 */
void connect_button_update_pixmap (GtkToggleButton *, int);
#endif

==> gnomemeeting-0.96.1.tar.bz2: gnomemeeting-0.96.1/src/toolbar.h <==

/* GnomeMeeting -- A Video-Conferencing application
 * Copyright (C) 2000-2001 Damien Sandras
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *                        toolbar.h  -  description
 *                        -------------------------
 *   begin                : Sat Dec 23 2000
 *   copyright            : (C) 2000-2001 by Damien Sandras
 *   description          : This file contains all the functions needed to
 *                          create the toolbar.
 *   email                : dsandras@seconix.com
 *
 */


#ifndef _TOOLBAR_H_
#define _TOOLBAR_H_

#include <gtk/gtk.h>
#include "common.h"


/* DESCRIPTION  :  /
 * BEHAVIOR     :  Create the main toolbar and return a pointer to the newly
 *                 created toolbar.
 * PRE          :  /
 */
GtkWidget *gnomemeeting_init_main_toolbar (void);


/* DESCRIPTION  :  /
 * BEHAVIOR     :  Create the left toolbar and return a pointer to the newly
 *                 created toolbar.
 * PRE          :  /
 */
GtkWidget *gnomemeeting_init_left_toolbar (void);


/* DESCRIPTION  :  /
 * BEHAVIOR     :  Updates the connect button.
 * PRE          :  /
 */
void connect_button_update_pixmap (GtkToggleButton *, int);
#endif
